#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-refactor-plugin
version:              2.3.0.0
visibility:           public
id:                   hls-refactor-plugin-2.3.0.0-59JFa2F3oznLA8e1Xihd9g
key:                  hls-refactor-plugin-2.3.0.0-59JFa2F3oznLA8e1Xihd9g
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           zubin.duggal@gmail.com
author:               The Haskell IDE Team
synopsis:             Exactprint refactorings for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  c2623d79216f8df10b3d7caa91c1cd0a
exposed:              True
exposed-modules:
    Development.IDE.GHC.Compat.ExactPrint Development.IDE.GHC.Dump
    Development.IDE.GHC.ExactPrint Development.IDE.Plugin.CodeAction
    Development.IDE.Plugin.CodeAction.Util

hidden-modules:
    Development.IDE.Plugin.CodeAction.Args
    Development.IDE.Plugin.CodeAction.ExactPrint
    Development.IDE.Plugin.CodeAction.PositionIndexed
    Development.IDE.Plugin.Plugins.AddArgument
    Development.IDE.Plugin.Plugins.Diagnostic
    Development.IDE.Plugin.Plugins.FillHole
    Development.IDE.Plugin.Plugins.FillTypeWildcard
    Development.IDE.Plugin.Plugins.ImportUtils

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-refactor-plugin-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-refactor-plugin-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-refactor-plugin-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-refactor-plugin
hs-libraries:         HShls-refactor-plugin-2.3.0.0-59JFa2F3oznLA8e1Xihd9g
depends:
    aeson-2.2.1.0-Def4REbZAAu5MJxZQtCFDo base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz deepseq-1.4.8.1
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO
    extra-1.7.16-7J4flVDuVp79ZQl3ULvjo5 ghc-9.6.6 ghc-boot-9.6.6
    ghc-exactprint-1.7.1.0-EjrTaLmfueE8YeSqB1isRU
    ghcide-2.3.0.0-IdkJBZfUYYi78XHYVaeExs
    hls-graph-2.3.0.0-8cbaJWEq6LS58TCEqe7zAd
    hls-plugin-api-2.3.0.0-9Ew4wivxLgiCEnvMUZLJta
    lens-5.3.4-59xiJiOdHtvHZvlFC0zvFo
    lsp-2.2.0.0-3kjUeEaFVQXJXrrpQSwskJ mtl-2.3.1
    parser-combinators-1.3.1-8aQ8dKOwDVmFxT1S1WvW6m
    regex-applicative-0.3.4-DXt3PjNzlQCnbf2JO7odf
    regex-tdfa-1.3.2.5-1f9YjGvAf24EdoqRc3t0wn
    retrie-1.2.3-AS0vqorjOaOAXzzTT7ExAe
    syb-0.7.3-K9V4mFAbfAKIQTGSYawcKu text-2.0.2
    text-rope-0.3-7aPOTM1xmqdIhyvkI25VZg time-1.12.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-CeHDQtVso2t69dwLJnxrjh

haddock-interfaces:
    /usr/share/doc/haskell-hls-refactor-plugin/html/hls-refactor-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-refactor-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

